==> pip_services3_rpc-3.0.3.tar.gz: pip_services3_rpc-3.0.3/setup.py <==
"""
Pip.Services Rpc
----------------------

Pip.Services is an open-source library of basic microservices.
pip_services3_rpc provides synchronous and asynchronous communication components.

Links
`````

* `website <http://github.com/pip-services-python/>`_
* `development version <http://github.com/pip-services3-python/pip-services3-rpc-python>`

"""

from setuptools import setup
from setuptools import find_packages
import json

with open('component.json') as json_file:
    config = json.load(json_file)

setup(
    name='pip_services3_rpc',
    version=config['version'],
    url='http://github.com/pip-services3-python/pip-services3-rpc-python',
    license='MIT',
    author='Conceptual Vision Consulting LLC',
    author_email='seroukhov@gmail.com',
    description='Communication components for Pip.Services in Python',
    long_description=__doc__,
    packages=find_packages(exclude=['config', 'data', 'test']),
    include_package_data=True,
    zip_safe=True,
    platforms='any',
    install_requires=[
        'iso8601', 'PyYAML', 'bottle', 'requests', 'pip-services3-commons', 'pip-services3-components'
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]    
)

==> pip_services3_rpc-3.1.4.tar.gz: pip_services3_rpc-3.1.4/setup.py <==
"""
Pip.Services Rpc
----------------------

Pip.Services is an open-source library of basic microservices.
pip_services3_rpc provides synchronous and asynchronous communication components.

Links
`````

* `website <http://github.com/pip-services-python/>`_
* `development version <http://github.com/pip-services3-python/pip-services3-rpc-python>`

"""

from setuptools import setup
from setuptools import find_packages

try:
    readme = open('readme.md').read()
except:
    readme = __doc__

setup(
    name='pip_services3_rpc',
    version='3.1.4',
    url='http://github.com/pip-services3-python/pip-services3-rpc-python',
    license='MIT',
    author='Conceptual Vision Consulting LLC',
    author_email='seroukhov@gmail.com',
    description='Communication components for Pip.Services in Python',
    long_description=readme,
    long_description_content_type="text/markdown",
    packages=find_packages(exclude=['config', 'data', 'test']),
    include_package_data=True,
    zip_safe=True,
    platforms='any',
    install_requires=[
        'iso8601', 'PyYAML', 'pystache', 'pytest', 'numpy', 'pytz', 'bottle', 'requests', 'netifaces',
        'pip-services3-commons', 'pip-services3-components', 'cheroot', 'beaker'
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)
